@@ -10,6 +10,7 @@ else
 	T=-Tascii
 fi
 opts=
+safe=-S
 
 for i
 do
@@ -34,6 +35,14 @@ do
 	-T*)
 		# ignore other devices
 		;;
+	-S)
+		# safe behaviour
+		safe=-S
+		;;
+	-U)
+		# unsafe behaviour
+		safe=-U
+		;;
 	-u*)
 		# Solaris 2.2 `man' uses -u0; ignore it,
 		# since `less' and `more' can use the emboldening info.
@@ -58,4 +67,4 @@ done
 
 # This shell script is intended for use with man, so warnings are
 # probably not wanted.  Also load nroff-style character definitions.
-exec groff -Wall -mtty-char $T $opts ${1+"$@"}
+exec groff $safe -Wall -mtty-char $T $opts ${1+"$@"}
