@@ -2428,7 +2428,13 @@ bracket_node::~bracket_node()
 node *bracket_node::copy()
 {
   bracket_node *on = new bracket_node;
-  for (node *tem = list; tem; tem = tem->next)
+  node *last, *tem;
+  for (tem = list; tem; tem = tem->next) {
+    if (tem->next)
+      tem->next->last = tem;
+    last = tem;
+  }
+  for (tem = last; tem; tem = tem->last)
     on->bracket(tem->copy());
   return on;
 }
